@@ -26,11 +26,10 @@
 #include <sys/ioctl.h>
 #ifdef __FreeBSD__
 #  include <machine/soundcard.h>
-#  include <awe_voice.h>
 #elif defined(linux)
 #  include <linux/soundcard.h>
-#  include <linux/awe_voice.h>
 #endif
+#include <awe_voice.h>
 #include <getopt.h>
 #include "util.h"
 #include "seq.h"
@@ -82,7 +81,7 @@ static struct option long_options[] = {
 	{0,0,0,0},
 };
 
-#define OPTIONS "hvf:d:D:"
+#define OPTIONS "hvf:F:D:"
 static int file_passed = 0;
 
 int main(int argc, char **argv)
